@@ -22,15 +22,8 @@ except ImportError:
     # pandas is not installed
     pandas = None
 
-try:
-    from cStringIO import StringIO
-except ImportError:
-    # for python3
-    from io import BytesIO as StringIO
-try:
-    import queue
-except ImportError:
-    import Queue as queue
+from io import BytesIO as StringIO
+import queue
 
 _WAIT_SELECT_TIMEOUT = 10
 
@@ -46,7 +39,7 @@ class SqlUtilException(Exception):
 def __wait_select_inter(conn):
     """ Make the queries interruptable by Ctrl-C
 
-    Taken from http://initd.org/psycopg/articles/2014/07/20/cancelling-postgresql-statements-python/
+    Taken from http://initd.org/psycopg/articles/2014/07/20/cancelling-postgresql-statements-python/ # noqa
     """
     while True:
         try:
@@ -193,7 +186,7 @@ def __converter(qIn, qOut, endEvent, dtype, intNullVal):
             continue
         try:
             res = __fromrecords(tups, dtype=dtype, intNullVal=intNullVal)
-        except:
+        except Exception:
             print('Failed to convert input data into array')
             endEvent.set()
             raise
@@ -429,6 +422,9 @@ def get(query,
 
     cur.close()
 
+    if not connSupplied:
+        conn.close()
+
     if asDict:
         resDict = collections.OrderedDict()
         repeats = {}
@@ -521,7 +517,7 @@ def __create_schema(tableName, arrays, names, temp=False):
     outp = 'create %s table %s ' % (temp, tableName)
     outp1 = []
     for arr, name in zip(arrays, names):
-        outp1.append(name + ' ' + hash[arr.dtype.type])
+        outp1.append('"' + name + '" ' + hash[arr.dtype.type])
     return outp + '(' + ','.join(outp1) + ')'
 
 
@@ -543,7 +539,7 @@ def failure_cleanup(conn, connSupplied):
     if not connSupplied:
         try:
             conn.close()  # do not close if we were given the connection
-        except:
+        except Exception:
             pass
 
 
@@ -612,7 +608,16 @@ def upload(tableName,
 table/pandas/dictionary or provide a separate list of arrays and their names')
 
     arrays = [np.asarray(_) for _ in arrays]
-    repl_char = {' ': '_', '-': '_', '(': '_', ')': '_', '[': '_', ']': '_'}
+    repl_char = {
+        ' ': '_',
+        '-': '_',
+        '(': '_',
+        ')': '_',
+        '[': '_',
+        ']': '_',
+        '<': '_',
+        '>': '_'
+    }
     fixed_names = []
     for name in names:
         fixed_name = name + ''
@@ -696,19 +701,27 @@ def local_join(query,
                              host=host,
                              timeout=timeout,
                              port=port)
+    try:
+        upload(tableName,
+               arrays,
+               names,
+               conn=conn,
+               noCommit=True,
+               temp=True,
+               analyze=True)
+    except BaseException:
+        failure_cleanup(conn, connSupplied)
+        raise
+    try:
+        res = get(query,
+                  conn=conn,
+                  preamb=preamb,
+                  strLength=strLength,
+                  asDict=asDict)
+    except BaseException:
+        failure_cleanup(conn, connSupplied)
+        raise
 
-    upload(tableName,
-           arrays,
-           names,
-           conn=conn,
-           noCommit=True,
-           temp=True,
-           analyze=True)
-    res = get(query,
-              conn=conn,
-              preamb=preamb,
-              strLength=strLength,
-              asDict=asDict)
     conn.rollback()
 
     if not connSupplied:
